@@ -5,7 +5,6 @@ from eqsmart.main.consumer import Consumer
 from eqlink.components.remote_server import remote_server
 from eqlink.main.clent import fail_server_list
 import json
-import traceback
 
 protocol = {
     'type': 'call provider',
@@ -64,10 +63,12 @@ class RemoteCall:
         except Exception as e:
             print('[eqsmart] 远程调用失败！', e)
             remote_call = json.dumps({'code': 'remote_call_error', 'message': str(e)})
-            print(traceback.format_exc())
         ''' 调用结果判断 '''
         res = json.loads(remote_call)
-        if res['code'] == 'remote_call_error':
-            fail_server_list.append({'IP': provider_conf['IP'], 'PORT': provider_conf['PORT']})
-
+        try:
+            if res['code'] == 'remote_call_error':
+                fail_server_list.append({'IP': provider_conf['IP'], 'PORT': provider_conf['PORT']})
+        except Exception as e:
+            ''' 远程调用可能不返回 code '''
+            print('远程调用成功！', e)
         return res
